summaryrefslogtreecommitdiff
path: root/test/input/func_w0612.py
diff options
context:
space:
mode:
authorSylvain Th?nault <sylvain.thenault@logilab.fr>2013-05-07 09:42:13 +0200
committerSylvain Th?nault <sylvain.thenault@logilab.fr>2013-05-07 09:42:13 +0200
commit922c09836cce4a603b22a972149b57115a559f24 (patch)
treec3f8223283669a074bbcca4f309e784d15abde7e /test/input/func_w0612.py
parent5cbe6b872ac9e6b8f4f66313e4f16f1bb4031033 (diff)
downloadpylint-922c09836cce4a603b22a972149b57115a559f24.tar.gz
fix spelling of max-branchs option, now max-branches
Diffstat (limited to 'test/input/func_w0612.py')
-rw-r--r--test/input/func_w0612.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/input/func_w0612.py b/test/input/func_w0612.py
index e375671..57e139c 100644
--- a/test/input/func_w0612.py
+++ b/test/input/func_w0612.py
@@ -12,11 +12,11 @@ def function(matches):
print match
def visit_if(self, node):
- """increments the branchs counter"""
- branchs = 1
+ """increments the branches counter"""
+ branches = 1
# don't double count If nodes coming from some 'elif'
if node.orelse and len(node.orelse) > 1:
- branchs += 1
- self.inc_branch(branchs)
- self.stmts += branchs
+ branches += 1
+ self.inc_branch(branches)
+ self.stmts += branches